@@ -18,10 +18,11 @@ from typing import TYPE_CHECKING, Callable, Union
 from supertokens_python.ingredients.emaildelivery.types import \
     EmailDeliveryConfig
 from supertokens_python.recipe.emailpassword.types import \
-    TypeEmailPasswordEmailDeliveryInput
+    EmailTemplateVars
 
 from . import exceptions as ex
 from . import utils
+from .emaildelivery import services as emaildelivery_services
 from .recipe import EmailPasswordRecipe
 
 exceptions = ex
@@ -30,6 +31,7 @@ InputResetPasswordUsingTokenFeature = utils.InputResetPasswordUsingTokenFeature
 InputEmailVerificationConfig = utils.InputEmailVerificationConfig
 InputSignUpFeature = utils.InputSignUpFeature
 InputFormField = utils.InputFormField
+SMTPService = emaildelivery_services.SMTPService
 
 if TYPE_CHECKING:
     from supertokens_python.supertokens import AppInfo
@@ -42,7 +44,7 @@ def init(sign_up_feature: Union[utils.InputSignUpFeature, None] = None,
              utils.InputResetPasswordUsingTokenFeature, None] = None,
          email_verification_feature: Union[utils.InputEmailVerificationConfig, None] = None,
          override: Union[utils.InputOverrideConfig, None] = None,
-         email_delivery: Union[EmailDeliveryConfig[TypeEmailPasswordEmailDeliveryInput], None] = None
+         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None
          ) -> Callable[[AppInfo], RecipeModule]:
     return EmailPasswordRecipe.init(
         sign_up_feature,
