@@ -16,11 +16,14 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Callable
 
 from . import exceptions as ex
-from .recipe import EmailVerificationRecipe
 from . import utils
+from .emaildelivery import services as emaildelivery_services
+from .recipe import EmailVerificationRecipe
+
 InputOverrideConfig = utils.OverrideConfig
 ParentRecipeEmailVerificationConfig = utils.ParentRecipeEmailVerificationConfig
 exception = ex
+SMTPService = emaildelivery_services.SMTPService
 
 
 if TYPE_CHECKING:
