@@ -17,20 +17,20 @@ from supertokens_python.logger import log_debug_message
 from supertokens_python.recipe.passwordless.interfaces import (
     APIInterface, APIOptions, ConsumeCodeExpiredUserInputCodeError,
     ConsumeCodeIncorrectUserInputCodeError,
-    ConsumeCodePostExpiredUserInputCodeError, ConsumeCodePostGeneralError,
+    ConsumeCodePostExpiredUserInputCodeError,
     ConsumeCodePostIncorrectUserInputCodeError, ConsumeCodePostOkResult,
     ConsumeCodePostRestartFlowError, ConsumeCodeRestartFlowError,
-    CreateCodePostGeneralError, CreateCodePostOkResult,
-    CreateNewCodeForDeviceOkResult,
+    CreateCodePostOkResult, CreateNewCodeForDeviceOkResult,
     CreateNewCodeForDeviceUserInputCodeAlreadyUsedError,
-    EmailExistsGetOkResult, PhoneNumberExistsGetOkResult,
-    ResendCodePostGeneralError, ResendCodePostOkResult,
-    ResendCodePostRestartFlowError, TypePasswordlessEmailDeliveryInput)
+    EmailExistsGetOkResult, PasswordlessLoginEmailTemplateVars,
+    PhoneNumberExistsGetOkResult, ResendCodePostOkResult,
+    ResendCodePostRestartFlowError)
 from supertokens_python.recipe.passwordless.types import \
-    TypePasswordlessSmsDeliveryInput
+    PasswordlessLoginSMSTemplateVars
 from supertokens_python.recipe.passwordless.utils import (
     ContactEmailOnlyConfig, ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)
 from supertokens_python.recipe.session.asyncio import create_new_session
+from supertokens_python.types import GeneralErrorResponse
 
 from ..utils import PhoneOrEmailInput
 
@@ -40,7 +40,7 @@ class APIImplementation(APIInterface):
                                email: Union[str, None],
                                phone_number: Union[str, None],
                                api_options: APIOptions,
-                               user_context: Dict[str, Any]) -> Union[CreateCodePostOkResult, CreateCodePostGeneralError]:
+                               user_context: Dict[str, Any]) -> Union[CreateCodePostOkResult, GeneralErrorResponse]:
         user_input_code = None
         if api_options.config.get_custom_user_input_code is not None:
             user_input_code = await api_options.config.get_custom_user_input_code(user_context)
@@ -55,42 +55,40 @@ class APIImplementation(APIInterface):
         if flow_type in ('USER_INPUT_CODE', 'USER_INPUT_CODE_AND_MAGIC_LINK'):
             user_input_code = response.user_input_code
 
-        try:
-            if isinstance(api_options.config.contact_config, ContactEmailOnlyConfig) or \
-                    (isinstance(api_options.config.contact_config, ContactEmailOrPhoneConfig) and email is not None):
-                if email is None:
-                    raise Exception("Should never come here")
+        if isinstance(api_options.config.contact_config, ContactEmailOnlyConfig) or \
+                (isinstance(api_options.config.contact_config, ContactEmailOrPhoneConfig) and email is not None):
+            if email is None:
+                raise Exception("Should never come here")
+
+            log_debug_message("Sending passwordless login email to %s", email)
+            passwordless_email_delivery_input = PasswordlessLoginEmailTemplateVars(
+                email=email,
+                user_input_code=user_input_code,
+                url_with_link_code=magic_link,
+                code_life_time=response.code_life_time,
+                pre_auth_session_id=response.pre_auth_session_id
+            )
+            await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
+        elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
+            if phone_number is None:
+                raise Exception("Should never come here")
+            log_debug_message("Sending passwordless login SMS to %s", phone_number)
+            sms_input = PasswordlessLoginSMSTemplateVars(
+                phone_number=phone_number,
+                user_input_code=user_input_code,
+                url_with_link_code=magic_link,
+                code_life_time=response.code_life_time,
+                pre_auth_session_id=response.pre_auth_session_id,
+            )
+            await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
 
-                log_debug_message("Sending passwordless login email to %s", email)
-                passwordless_email_delivery_input = TypePasswordlessEmailDeliveryInput(
-                    email=email,
-                    user_input_code=user_input_code,
-                    url_with_link_code=magic_link,
-                    code_life_time=response.code_life_time,
-                    pre_auth_session_id=response.pre_auth_session_id
-                )
-                await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
-            elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
-                if phone_number is None:
-                    raise Exception("Should never come here")
-                log_debug_message("Sending passwordless login SMS to %s", phone_number)
-                sms_input = TypePasswordlessSmsDeliveryInput(
-                    phone_number=phone_number,
-                    user_input_code=user_input_code,
-                    url_with_link_code=magic_link,
-                    code_life_time=response.code_life_time,
-                    pre_auth_session_id=response.pre_auth_session_id,
-                )
-                await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
-        except Exception as e:
-            return CreateCodePostGeneralError(str(e))
         return CreateCodePostOkResult(response.device_id, response.pre_auth_session_id, flow_type)
 
     async def resend_code_post(self,
                                device_id: str,
                                pre_auth_session_id: str,
                                api_options: APIOptions,
-                               user_context: Dict[str, Any]) -> Union[ResendCodePostOkResult, ResendCodePostRestartFlowError, ResendCodePostGeneralError]:
+                               user_context: Dict[str, Any]) -> Union[ResendCodePostOkResult, ResendCodePostRestartFlowError, GeneralErrorResponse]:
         device_info = await api_options.recipe_implementation.list_codes_by_device_id(
             device_id=device_id,
             user_context=user_context
@@ -113,7 +111,7 @@ class APIImplementation(APIInterface):
             )
             if isinstance(response, CreateNewCodeForDeviceUserInputCodeAlreadyUsedError):
                 if number_of_tries_to_create_new_code >= 3:
-                    return ResendCodePostGeneralError(
+                    return GeneralErrorResponse(
                         'Failed to generate a one time code. Please try again')
                 continue
 
@@ -128,36 +126,33 @@ class APIImplementation(APIInterface):
                 if flow_type in ('USER_INPUT_CODE', 'USER_INPUT_CODE_AND_MAGIC_LINK'):
                     user_input_code = response.user_input_code
 
-                try:
-                    if isinstance(api_options.config.contact_config, ContactEmailOnlyConfig) or \
-                            (isinstance(api_options.config.contact_config,
-                                        ContactEmailOrPhoneConfig) and device_info.email is not None):
-                        if device_info.email is None:
-                            raise Exception("Should never come here")
+                if isinstance(api_options.config.contact_config, ContactEmailOnlyConfig) or \
+                        (isinstance(api_options.config.contact_config,
+                                    ContactEmailOrPhoneConfig) and device_info.email is not None):
+                    if device_info.email is None:
+                        raise Exception("Should never come here")
 
-                        log_debug_message("Sending passwordless login email to %s", device_info.email)
-                        passwordless_email_delivery_input = TypePasswordlessEmailDeliveryInput(
-                            email=device_info.email,
-                            user_input_code=user_input_code,
-                            url_with_link_code=magic_link,
-                            code_life_time=response.code_life_time,
-                            pre_auth_session_id=response.pre_auth_session_id
-                        )
-                        await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
-                    elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
-                        if device_info.phone_number is None:
-                            raise Exception("Should never come here")
-                        log_debug_message("Sending passwordless login SMS to %s", device_info.phone_number)
-                        sms_input = TypePasswordlessSmsDeliveryInput(
-                            phone_number=device_info.phone_number,
-                            user_input_code=user_input_code,
-                            url_with_link_code=magic_link,
-                            code_life_time=response.code_life_time,
-                            pre_auth_session_id=response.pre_auth_session_id,
-                        )
-                        await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
-                except Exception as e:
-                    return ResendCodePostGeneralError(str(e))
+                    log_debug_message("Sending passwordless login email to %s", device_info.email)
+                    passwordless_email_delivery_input = PasswordlessLoginEmailTemplateVars(
+                        email=device_info.email,
+                        user_input_code=user_input_code,
+                        url_with_link_code=magic_link,
+                        code_life_time=response.code_life_time,
+                        pre_auth_session_id=response.pre_auth_session_id
+                    )
+                    await api_options.email_delivery.ingredient_interface_impl.send_email(passwordless_email_delivery_input, user_context)
+                elif isinstance(api_options.config.contact_config, (ContactEmailOrPhoneConfig, ContactPhoneOnlyConfig)):
+                    if device_info.phone_number is None:
+                        raise Exception("Should never come here")
+                    log_debug_message("Sending passwordless login SMS to %s", device_info.phone_number)
+                    sms_input = PasswordlessLoginSMSTemplateVars(
+                        phone_number=device_info.phone_number,
+                        user_input_code=user_input_code,
+                        url_with_link_code=magic_link,
+                        code_life_time=response.code_life_time,
+                        pre_auth_session_id=response.pre_auth_session_id,
+                    )
+                    await api_options.sms_delivery.ingredient_interface_impl.send_sms(sms_input, user_context)
                 return ResendCodePostOkResult()
             return ResendCodePostRestartFlowError()
 
@@ -167,7 +162,7 @@ class APIImplementation(APIInterface):
                                 device_id: Union[str, None],
                                 link_code: Union[str, None],
                                 api_options: APIOptions,
-                                user_context: Dict[str, Any]) -> Union[ConsumeCodePostOkResult, ConsumeCodePostRestartFlowError, ConsumeCodePostGeneralError, ConsumeCodePostIncorrectUserInputCodeError, ConsumeCodePostExpiredUserInputCodeError]:
+                                user_context: Dict[str, Any]) -> Union[ConsumeCodePostOkResult, ConsumeCodePostRestartFlowError, ConsumeCodePostIncorrectUserInputCodeError, ConsumeCodePostExpiredUserInputCodeError, GeneralErrorResponse]:
         response = await api_options.recipe_implementation.consume_code(
             pre_auth_session_id=pre_auth_session_id,
             user_input_code=user_input_code,
@@ -197,10 +192,10 @@ class APIImplementation(APIInterface):
             session=session
         )
 
-    async def email_exists_get(self, email: str, api_options: APIOptions, user_context: Dict[str, Any]) -> EmailExistsGetOkResult:
+    async def email_exists_get(self, email: str, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[EmailExistsGetOkResult, GeneralErrorResponse]:
         response = await api_options.recipe_implementation.get_user_by_email(email, user_context)
         return EmailExistsGetOkResult(exists=response is not None)
 
-    async def phone_number_exists_get(self, phone_number: str, api_options: APIOptions, user_context: Dict[str, Any]) -> PhoneNumberExistsGetOkResult:
+    async def phone_number_exists_get(self, phone_number: str, api_options: APIOptions, user_context: Dict[str, Any]) -> Union[PhoneNumberExistsGetOkResult, GeneralErrorResponse]:
         response = await api_options.recipe_implementation.get_user_by_phone_number(phone_number, user_context)
         return PhoneNumberExistsGetOkResult(exists=response is not None)
