@@ -295,9 +295,11 @@ def validate_and_normalise_user_input(app_info: AppInfo,
         error_handlers = InputErrorHandlers()
 
     if (cookie_same_site == 'none') and \
-            not cookie_secure and \
-            not (top_level_api_domain == 'localhost' or is_an_ip_address(top_level_api_domain)) and \
-            not (top_level_website_domain == 'localhost' or is_an_ip_address(top_level_website_domain)):
+            not cookie_secure and not (
+                (top_level_api_domain == 'localhost' or is_an_ip_address(top_level_api_domain)) and
+                (top_level_website_domain == 'localhost' or is_an_ip_address(top_level_website_domain))):
+        # We can allow insecure cookie when both website & API domain are localhost or an IP
+        # When either of them is a different domain, API domain needs to have https and a secure cookie to work
         raise_general_exception('Since your API and website domain are different, for sessions to work, please use '
                                 'https on your apiDomain and don\'t set cookieSecure to false.')
 
