@@ -31,10 +31,11 @@ class Github(Provider):
                  authorisation_redirect: Union[None, Dict[str, Union[str, Callable[[
                      BaseRequest], str]]]] = None,
                  is_default: bool = False):
-        super().__init__('github', client_id, is_default)
+        super().__init__('github', is_default)
         default_scopes = ["read:user", "user:email"]
         if scope is None:
             scope = default_scopes
+        self.client_id = client_id
         self.client_secret = client_secret
         self.scopes = list(set(scope))
         self.access_token_api_url = 'https://github.com/login/oauth/access_token'
@@ -88,3 +89,6 @@ class Github(Provider):
 
     def get_redirect_uri(self, user_context: Dict[str, Any]) -> Union[None, str]:
         return None
+
+    def get_client_id(self, user_context: Dict[str, Any]) -> str:
+        return self.client_id
