@@ -16,11 +16,18 @@ from __future__ import annotations
 from typing import Any, Dict, Union
 
 from supertokens_python.recipe.emailpassword.interfaces import (
-    CreateResetPasswordResult, RecipeInterface, ResetPasswordUsingTokenResult,
-    SignInResult, SignUpResult, UpdateEmailOrPasswordResult)
+    CreateResetPasswordOkResult, CreateResetPasswordWrongUserIdError,
+    RecipeInterface, ResetPasswordUsingTokenOkResult,
+    ResetPasswordUsingTokenInvalidTokenError, SignInOkResult,
+    SignInWrongCredentialsError, SignUpEmailAlreadyExistsError,
+    SignUpOkResult, UpdateEmailOrPasswordEmailAlreadyExistsError,
+    UpdateEmailOrPasswordOkResult,
+    UpdateEmailOrPasswordUnknownUserIdError)
 from supertokens_python.recipe.emailpassword.types import User
-from supertokens_python.recipe.thirdpartyemailpassword.interfaces import \
-    RecipeInterface as ThirdPartyEmailPasswordRecipeInterface
+
+from ..interfaces import (
+    RecipeInterface as ThirdPartyEmailPasswordRecipeInterface,
+    EmailPasswordSignInOkResult, EmailPasswordSignUpOkResult)
 
 
 class RecipeImplementation(RecipeInterface):
@@ -47,18 +54,26 @@ class RecipeImplementation(RecipeInterface):
 
         return None
 
-    async def create_reset_password_token(self, user_id: str, user_context: Dict[str, Any]) -> CreateResetPasswordResult:
+    async def create_reset_password_token(self, user_id: str, user_context: Dict[str, Any]) -> Union[CreateResetPasswordOkResult, CreateResetPasswordWrongUserIdError]:
         return await self.recipe_implementation.create_reset_password_token(user_id, user_context)
 
-    async def reset_password_using_token(self, token: str, new_password: str, user_context: Dict[str, Any]) -> ResetPasswordUsingTokenResult:
+    async def reset_password_using_token(self, token: str, new_password: str, user_context: Dict[str, Any]) -> Union[ResetPasswordUsingTokenOkResult, ResetPasswordUsingTokenInvalidTokenError]:
         return await self.recipe_implementation.reset_password_using_token(token, new_password, user_context)
 
-    async def sign_in(self, email: str, password: str, user_context: Dict[str, Any]) -> SignInResult:
-        return await self.recipe_implementation.emailpassword_sign_in(email, password, user_context)
+    async def sign_in(self, email: str, password: str, user_context: Dict[str, Any]) -> Union[SignInOkResult, SignInWrongCredentialsError]:
+        result = await self.recipe_implementation.emailpassword_sign_in(email, password, user_context)
+        if isinstance(result, EmailPasswordSignInOkResult):
+            return SignInOkResult(
+                User(result.user.user_id, result.user.email, result.user.time_joined))
+        return result
 
-    async def sign_up(self, email: str, password: str, user_context: Dict[str, Any]) -> SignUpResult:
-        return await self.recipe_implementation.emailpassword_sign_up(email, password, user_context)
+    async def sign_up(self, email: str, password: str, user_context: Dict[str, Any]) -> Union[SignUpOkResult, SignUpEmailAlreadyExistsError]:
+        result = await self.recipe_implementation.emailpassword_sign_up(email, password, user_context)
+        if isinstance(result, EmailPasswordSignUpOkResult):
+            return SignUpOkResult(
+                User(result.user.user_id, result.user.email, result.user.time_joined))
+        return result
 
     async def update_email_or_password(self, user_id: str, email: Union[str, None],
-                                       password: Union[str, None], user_context: Dict[str, Any]) -> UpdateEmailOrPasswordResult:
+                                       password: Union[str, None], user_context: Dict[str, Any]) -> Union[UpdateEmailOrPasswordOkResult, UpdateEmailOrPasswordEmailAlreadyExistsError, UpdateEmailOrPasswordUnknownUserIdError]:
         return await self.recipe_implementation.update_email_or_password(user_id, email, password, user_context)
