@@ -21,16 +21,18 @@ from supertokens_python.ingredients.emaildelivery.types import \
     EmailDeliveryConfig
 from supertokens_python.normalised_url_path import NormalisedURLPath
 from supertokens_python.querier import Querier
+from supertokens_python.recipe.emailverification.types import \
+    EmailTemplateVars as EmailVerificationEmailTemplateVars
 from supertokens_python.recipe.emailverification.types import \
     EmailVerificationIngredients
 from supertokens_python.recipe.passwordless.types import \
     PasswordlessIngredients
 from supertokens_python.recipe.thirdparty.provider import Provider
-from supertokens_python.recipe.thirdparty.types import (
-    ThirdPartyIngredients, TypeThirdPartyEmailDeliveryInput)
+from supertokens_python.recipe.thirdparty.types import \
+    EmailTemplateVars as ThirdPartyEmailTemplateVars
+from supertokens_python.recipe.thirdparty.types import ThirdPartyIngredients
 from supertokens_python.recipe.thirdpartypasswordless.types import (
-    ThirdPartyPasswordlessIngredients,
-    TypeThirdPartyPasswordlessEmailDeliveryInput)
+    EmailTemplateVars, ThirdPartyPasswordlessIngredients)
 from supertokens_python.recipe_module import APIHandled, RecipeModule
 
 from ..passwordless.utils import ContactConfig, PhoneOrEmailInput
@@ -68,30 +70,27 @@ from ..emailverification.interfaces import (
     CreateEmailVerificationTokenEmailAlreadyVerifiedError,
     CreateEmailVerificationTokenOkResult)
 from ..emailverification.interfaces import RecipeInterface as EVRecipeInterface
-from ..emailverification.interfaces import \
-    TypeEmailVerificationEmailDeliveryInput
 from ..emailverification.utils import OverrideConfig as EVOverrideConfig
 from ..passwordless import PasswordlessRecipe
 from ..passwordless.interfaces import APIInterface as PasswordlessAPIInterface
+from ..passwordless.interfaces import PasswordlessLoginEmailTemplateVars
 from ..passwordless.interfaces import \
     RecipeInterface as PasswordlessRecipeInterface
-from ..passwordless.interfaces import TypePasswordlessEmailDeliveryInput
 from ..passwordless.utils import OverrideConfig as PlessOverrideConfig
 from ..thirdparty.interfaces import APIInterface as ThirdPartyAPIInterface
 from ..thirdparty.interfaces import \
     RecipeInterface as ThirdPartyRecipeInterface
 from .exceptions import SupertokensThirdPartyPasswordlessError
 from .interfaces import APIInterface, RecipeInterface
-from .types import (TypeThirdPartyPasswordlessEmailDeliveryInput,
-                    TypeThirdPartyPasswordlessSmsDeliveryInput)
+from .types import EmailTemplateVars, SMSTemplateVars
 from .utils import InputOverrideConfig, validate_and_normalise_user_input
 
 
 class ThirdPartyPasswordlessRecipe(RecipeModule):
     recipe_id = 'thirdpartypasswordless'
     __instance = None
-    email_delivery: EmailDeliveryIngredient[TypeThirdPartyPasswordlessEmailDeliveryInput]
-    sms_delivery: SMSDeliveryIngredient[TypeThirdPartyPasswordlessSmsDeliveryInput]
+    email_delivery: EmailDeliveryIngredient[EmailTemplateVars]
+    sms_delivery: SMSDeliveryIngredient[SMSTemplateVars]
 
     def __init__(self, recipe_id: str, app_info: AppInfo,
                  contact_config: ContactConfig,
@@ -105,8 +104,8 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
                  email_verification_recipe: Union[EmailVerificationRecipe, None] = None,
                  third_party_recipe: Union[ThirdPartyRecipe, None] = None,
                  passwordless_recipe: Union[PasswordlessRecipe, None] = None,
-                 email_delivery: Union[EmailDeliveryConfig[TypeThirdPartyPasswordlessEmailDeliveryInput], None] = None,
-                 sms_delivery: Union[SMSDeliveryConfig[TypeThirdPartyPasswordlessSmsDeliveryInput], None] = None,
+                 email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
+                 sms_delivery: Union[SMSDeliveryConfig[SMSTemplateVars], None] = None,
                  ):
         super().__init__(recipe_id, app_info)
         self.config = validate_and_normalise_user_input(self,
@@ -179,7 +178,7 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
             else:
                 self.config.email_verification_feature.override.functions = email_verification_override
 
-            ev_email_delivery = cast(EmailDeliveryIngredient[TypeEmailVerificationEmailDeliveryInput], self.email_delivery)
+            ev_email_delivery = cast(EmailDeliveryIngredient[EmailVerificationEmailTemplateVars], self.email_delivery)
             ev_ingredients = EmailVerificationIngredients(ev_email_delivery)
             self.email_verification_recipe = EmailVerificationRecipe(recipe_id, app_info,
                                                                      self.config.email_verification_feature, ev_ingredients)
@@ -194,7 +193,7 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
                 return get_passwordless_interface_impl(self.api_implementation)
 
             pless_email_delivery = cast(
-                EmailDeliveryIngredient[TypePasswordlessEmailDeliveryInput],
+                EmailDeliveryIngredient[PasswordlessLoginEmailTemplateVars],
                 self.email_delivery
             )
             pless_sms_delivery = self.sms_delivery
@@ -223,7 +222,7 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
             self.third_party_recipe: Union[ThirdPartyRecipe, None] = None
 
             if len(self.config.providers) != 0:
-                tp_email_delivery = cast(EmailDeliveryIngredient[TypeThirdPartyEmailDeliveryInput], self.email_delivery)
+                tp_email_delivery = cast(EmailDeliveryIngredient[ThirdPartyEmailTemplateVars], self.email_delivery)
                 tp_ingredients = ThirdPartyIngredients(tp_email_delivery)
                 self.third_party_recipe = ThirdPartyRecipe(
                     recipe_id,
@@ -299,8 +298,8 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
                  PhoneOrEmailInput, Dict[str, Any]], Awaitable[str]], None] = None,
              get_custom_user_input_code: Union[Callable[[Dict[str, Any]], Awaitable[str]], None] = None,
              email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
-             email_delivery: Union[EmailDeliveryConfig[TypeThirdPartyPasswordlessEmailDeliveryInput], None] = None,
-             sms_delivery: Union[SMSDeliveryConfig[TypeThirdPartyPasswordlessSmsDeliveryInput], None] = None,
+             email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
+             sms_delivery: Union[SMSDeliveryConfig[SMSTemplateVars], None] = None,
              override: Union[InputOverrideConfig, None] = None,
              providers: Union[List[Provider], None] = None):
         def func(app_info: AppInfo):
@@ -340,10 +339,13 @@ class ThirdPartyPasswordlessRecipe(RecipeModule):
         if user_info is None:
             raise Exception('Unknown User ID provided')
         if user_info.third_party_info is None:
-            # this is a passwordless user.. so we always return some random email,
-            # and in the function for isEmailVerified, we will check if the user
-            # is a passwordless user, and if they are, we will return true in there
-            return "_____supertokens_passwordless_user@supertokens.com"
+            if user_info.email is not None:
+                return user_info.email
+            # this is a passwordless user with only a phone number.
+            # returning an empty string here is not a problem since
+            # we override the email verification functions above to
+            # send that the email is already verified for passwordless users.
+            return ""
         if user_info.email is None:
             raise Exception("Should never come here")
         return user_info.email
