@@ -19,8 +19,8 @@ from supertokens_python.recipe.passwordless.interfaces import (
     DeleteUserInfoOkResult, DeleteUserInfoUnknownUserIdError)
 
 from .. import asyncio, interfaces
-from ..types import (TypeThirdPartyPasswordlessEmailDeliveryInput,
-                     TypeThirdPartyPasswordlessSmsDeliveryInput, User)
+from ..types import (EmailTemplateVars,
+                     SMSTemplateVars, User)
 
 
 def create_email_verification_token(user_id: str, user_context: Union[None, Dict[str, Any]] = None):
@@ -164,9 +164,9 @@ def passwordlessSigninup(email: Union[str, None], phone_number: Union[str,
         email=email, phone_number=phone_number, user_context=user_context))
 
 
-def send_email(input_: TypeThirdPartyPasswordlessEmailDeliveryInput, user_context: Union[None, Dict[str, Any]] = None):
+def send_email(input_: EmailTemplateVars, user_context: Union[None, Dict[str, Any]] = None):
     return sync(asyncio.send_email(input_, user_context))
 
 
-def send_sms(input_: TypeThirdPartyPasswordlessSmsDeliveryInput, user_context: Union[None, Dict[str, Any]] = None):
+def send_sms(input_: SMSTemplateVars, user_context: Union[None, Dict[str, Any]] = None):
     return sync(asyncio.send_sms(input_, user_context))
