@@ -165,6 +165,9 @@ class Supertokens:
                  mode: Union[Literal['asgi', 'wsgi'], None],
                  telemetry: Union[bool, None]
                  ):
+        if not isinstance(app_info, InputAppInfo):  # type: ignore
+            raise ValueError('app_info must be an instance of InputAppInfo')
+
         self.app_info = AppInfo(
             app_info.app_name,
             app_info.api_domain,
@@ -196,7 +199,10 @@ class Supertokens:
                 environ['SUPERTOKENS_ENV'] != 'testing')
 
         if telemetry:
-            execute_async(self.app_info.mode, self.send_telemetry)
+            try:
+                execute_async(self.app_info.mode, self.send_telemetry)
+            except Exception:
+                pass  # Do not stop app startup if telemetry fails
 
     async def send_telemetry(self):
         # If telemetry is enabled manually and the app is running in testing mode,
